pub struct EventEndpoint { /* private fields */ }Expand description
An event endpoint.
Implementations
Sourceimpl EventEndpoint
impl EventEndpoint
Sourcepub fn id(&self) -> &EndpointId
pub fn id(&self) -> &EndpointId
The endpoint’s identifier (or name).
Sourcepub fn direction(&self) -> EndpointDirection
pub fn direction(&self) -> EndpointDirection
The endpoint’s direction.
Sourcepub fn annotation(&self) -> &Annotation
pub fn annotation(&self) -> &Annotation
The endpoint’s annotation.
Sourcepub fn type_index(&self, ty: TypeRef<'_>) -> Option<EndpointTypeIndex>
pub fn type_index(&self, ty: TypeRef<'_>) -> Option<EndpointTypeIndex>
The index of the given type in the endpoint’s type list.
Sourcepub fn get_type(&self, index: EndpointTypeIndex) -> Option<&Type>
pub fn get_type(&self, index: EndpointTypeIndex) -> Option<&Type>
The type at the given index in the endpoint’s type list.