Performer

Struct Performer 

pub struct Performer { /* private fields */ }
A Cmajor performer.

Implementations

Source

impl Performer

pub fn set_block_size(&mut self, num_frames: u32)

Sets the block size of the performer.

pub fn advance(&mut self)

Renders the next block of frames.

pub fn endpoint_info<T>(&self, Endpoint: Endpoint<T>) -> Option<&EndpointInfo>
where T: EndpointType,

Returns information about a given endpoint.

pub fn set<T>( &mut self, endpoint: Endpoint<InputValue<T>>, value: T, ) -> T::Output
where T: SetInputValue,

Set the value of an endpoint.

pub fn get<T>(&mut self, endpoint: Endpoint<OutputValue<T>>) -> T::Output<'_>
where T: GetOutputValue,

Get the value of an endpoint.

pub fn post<'a>( &mut self, endpoint: Endpoint<InputEvent>, event: impl Into<ValueRef<'a>>, ) -> Result<(), EndpointError>

Post an event to an endpoint.

pub fn fetch( &mut self, endpoint: Endpoint<OutputEvent>, callback: impl FnMut(usize, ValueRef<'_>), ) -> Result<(), EndpointError>

Fetch the events received from an endpoint.

pub fn read<T>(&self, endpoint: Endpoint<OutputStream<T>>, buffer: &mut [T])
where T: StreamType,

Read frames from an input stream.

pub fn write<T>(&self, endpoint: Endpoint<InputStream<T>>, buffer: &[T])
where T: StreamType,

Write frames to an output stream.

pub fn get_xruns(&self) -> usize

Returns the number of times the performer has over/under-run.

pub fn get_max_block_size(&self) -> u32

Returns the maximum number of frames that can be processed in a single call to advance.

pub fn get_latency(&self) -> f64

Returns the performers internal latency in frames.

pub fn get_string(&self, StringHandle: StringHandle) -> Option<&str>

Returns the string associated with a handle.